==> beast-0.4.1.tar.gz: beast-0.4.1/bse/bsewaveosc.gen-proc.c <==

/**
 ** Generated data (by mkcproc.pl)
 **/
#line 1 "bsewaveosc.proc"

#include        <bse/bseplugin.h>
#include        <bse/bsewaveosc.h>
#include        <bse/bseprocedure.h>

#line 25 "bsewaveosc.proc"


/* --- request-pcm-position --- */
static GType type_id_request_pcm_position = 0;
static void
request_pcm_position_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 27 "bsewaveosc.proc"
 {
#line 29 "bsewaveosc.proc"
  *(in_pspecs++) = g_param_spec_object ("wosc", NULL, "Wave Oscilator",
			       BSE_TYPE_WAVE_OSC, BSE_PARAM_DEFAULT);
#line 28 "bsewaveosc.proc"
  proc->help = "Request emission of the ::notify_pcm_position signal.";
#line 22 "bsewaveosc.proc"
  proc->author = "Tim Janik <timj@gtk.org>";
#line 23 "bsewaveosc.proc"
  proc->copyright = "Tim Janik";
#line 24 "bsewaveosc.proc"
  proc->date = "2002";
#line 31 "bsewaveosc.proc"
}  }
static BseErrorType
#line 31 "bsewaveosc.proc"
request_pcm_position_exec (BseProcedureClass *proc,
	const GValue      *in_values,
	GValue            *out_values)
#line 34 "bsewaveosc.proc"
{
#line 35 "bsewaveosc.proc"
  
  BseWaveOsc *self = g_value_get_object (in_values++);
  
#line 38 "bsewaveosc.proc"
  
  if (!BSE_IS_WAVE_OSC (self))
    return BSE_ERROR_PROC_PARAM_INVAL;
  
  bse_wave_osc_request_pcm_position (self, -1);
  
  return BSE_ERROR_NONE;
}

/* --- pcm-seek-perc --- */
static GType type_id_pcm_seek_perc = 0;
static void
pcm_seek_perc_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 47 "bsewaveosc.proc"
 {
#line 49 "bsewaveosc.proc"
  *(in_pspecs++) = g_param_spec_object ("wosc", NULL, "Wave Oscilator",
			       BSE_TYPE_WAVE_OSC, BSE_PARAM_DEFAULT);
  *(in_pspecs++) = g_param_spec_float ("pos_perc", NULL, NULL,
			      0, 100, 0,
			      BSE_PARAM_DEFAULT);
#line 48 "bsewaveosc.proc"
  proc->help = "Seek oscillator to a given pcm percentage during playback.";
#line 22 "bsewaveosc.proc"
  proc->author = "Tim Janik <timj@gtk.org>";
#line 23 "bsewaveosc.proc"
  proc->copyright = "Tim Janik";
#line 24 "bsewaveosc.proc"
  proc->date = "2002";
#line 54 "bsewaveosc.proc"
}  }
static BseErrorType
#line 54 "bsewaveosc.proc"
pcm_seek_perc_exec (BseProcedureClass *proc,
	const GValue      *in_values,
	GValue            *out_values)
#line 57 "bsewaveosc.proc"
{
#line 58 "bsewaveosc.proc"
  
  BseWaveOsc *self = g_value_get_object (in_values++);
  gfloat      pos  = g_value_get_float (in_values++);
  
#line 62 "bsewaveosc.proc"
  
  if (!BSE_IS_WAVE_OSC (self))
    return BSE_ERROR_PROC_PARAM_INVAL;
  
  bse_wave_osc_request_pcm_position (self, CLAMP (pos, 0, 100));
  
  return BSE_ERROR_NONE;
}

/* --- Export to BSE --- */
BSE_EXPORTS_BEGIN (BSE_PLUGIN_NAME);
BSE_EXPORT_PROCEDURES = {
  { &type_id_request_pcm_position, "BseWaveOsc+request-pcm-position", NULL, 0, request_pcm_position_setup, request_pcm_position_exec, NULL, "/Method/BseWaveOsc/General/Request Pcm Position", { 0, }, },
  { &type_id_pcm_seek_perc, "BseWaveOsc+pcm-seek-perc", NULL, 0, pcm_seek_perc_setup, pcm_seek_perc_exec, NULL, "/Method/BseWaveOsc/General/Pcm Seek Perc", { 0, }, },
  { NULL, },
};
BSE_EXPORTS_END;

/**
 ** Generated data ends here
 **/

==> beast-0.5.1.tar.gz: beast-0.5.1/bse/bsewaveosc.gen-proc.c <==

/**
 ** Generated data (by mkcproc.pl)
 **/
#line 1 "bsewaveosc.proc"

#include        <bse/bseplugin.h>
#include        <bse/bsewaveosc.h>
#include        <bse/bseprocedure.h>

#line 24 "bsewaveosc.proc"


/* --- request-pcm-position --- */
static GType type_id_request_pcm_position = 0;
static void
request_pcm_position_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 26 "bsewaveosc.proc"
 {
#line 28 "bsewaveosc.proc"
  *(in_pspecs++) = bse_param_spec_object ("wosc", NULL, "Wave Oscilator",
				 BSE_TYPE_WAVE_OSC, SFI_PARAM_DEFAULT);
#line 27 "bsewaveosc.proc"
  proc->help = "Request emission of the ::notify_pcm_position signal.";
#line 22 "bsewaveosc.proc"
  proc->authors = "Tim Janik <timj@gtk.org>";
#line 23 "bsewaveosc.proc"
  proc->copyright = "Copyright (C) 2002 Tim Janik";
#line 30 "bsewaveosc.proc"
}  }
static BseErrorType
#line 30 "bsewaveosc.proc"
request_pcm_position_exec (BseProcedureClass *proc,
	const GValue      *in_values,
	GValue            *out_values)
#line 33 "bsewaveosc.proc"
{
#line 34 "bsewaveosc.proc"
  
  BseWaveOsc *self = bse_value_get_object (in_values++);
  
#line 37 "bsewaveosc.proc"
  
  if (!BSE_IS_WAVE_OSC (self))
    return BSE_ERROR_PROC_PARAM_INVAL;
  
  bse_wave_osc_request_pcm_position (self, -1);
  
  return BSE_ERROR_NONE;
}

/* --- pcm-seek-perc --- */
static GType type_id_pcm_seek_perc = 0;
static void
pcm_seek_perc_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 46 "bsewaveosc.proc"
 {
#line 48 "bsewaveosc.proc"
  *(in_pspecs++) = bse_param_spec_object ("wosc", NULL, "Wave Oscilator",
				 BSE_TYPE_WAVE_OSC, SFI_PARAM_DEFAULT);
  *(in_pspecs++) = sfi_pspec_real ("pos_perc", NULL, NULL,
			  0, 0, 100, 1,
			  SFI_PARAM_DEFAULT);
#line 47 "bsewaveosc.proc"
  proc->help = "Seek oscillator to a given pcm percentage during playback.";
#line 22 "bsewaveosc.proc"
  proc->authors = "Tim Janik <timj@gtk.org>";
#line 23 "bsewaveosc.proc"
  proc->copyright = "Copyright (C) 2002 Tim Janik";
#line 53 "bsewaveosc.proc"
}  }
static BseErrorType
#line 53 "bsewaveosc.proc"
pcm_seek_perc_exec (BseProcedureClass *proc,
	const GValue      *in_values,
	GValue            *out_values)
#line 56 "bsewaveosc.proc"
{
#line 57 "bsewaveosc.proc"
  
  BseWaveOsc *self = bse_value_get_object (in_values++);
  gfloat      pos  = sfi_value_get_real (in_values++);
  
#line 61 "bsewaveosc.proc"
  
  if (!BSE_IS_WAVE_OSC (self))
    return BSE_ERROR_PROC_PARAM_INVAL;
  
  bse_wave_osc_request_pcm_position (self, CLAMP (pos, 0, 100));
  
  return BSE_ERROR_NONE;
}

/* --- Export to BSE --- */
BSE_EXPORTS_BEGIN (BSE_PLUGIN_NAME);
BSE_EXPORT_PROCEDURES = {
  { &type_id_request_pcm_position, "BseWaveOsc+request-pcm-position", NULL, 0, request_pcm_position_setup, request_pcm_position_exec, NULL, "/Method/BseWaveOsc/General/Request Pcm Position", { 0, }, },
  { &type_id_pcm_seek_perc, "BseWaveOsc+pcm-seek-perc", NULL, 0, pcm_seek_perc_setup, pcm_seek_perc_exec, NULL, "/Method/BseWaveOsc/General/Pcm Seek Perc", { 0, }, },
  { NULL, },
};
BSE_EXPORTS_END;

/**
 ** Generated data ends here
 **/
